@@ -1,7 +1,8 @@
-VERSION = (0, 0, 4)
+VERSION = (1, 0, 0)
 __version__ = '.'.join(map(str, VERSION))
 
-from django_nose.runner import NoseTestSuiteRunner
+from django_nose.runner import *
+from django_nose.testcases import *
 
 
 # Django < 1.2 compatibility.
