@@ -1,6 +1,31 @@
+import os.path
+import sys
+
+from nose.plugins.base import Plugin
+
+from django.conf import settings
+from django.db.models.loading import get_apps, load_app
+from django.test.testcases import TransactionTestCase
 
 
-class ResultPlugin(object):
+class AlwaysOnPlugin(Plugin):
+    """A plugin that takes no options and is always enabled"""
+
+    def options(self, parser, env):
+        """Avoid adding a ``--with`` option for this plugin.
+
+        We don't have any options, and this plugin is always enabled, so we
+        don't want to use superclass's ``options()`` method which would add a
+        ``--with-*`` option.
+
+        """
+
+    def configure(self, *args, **kw_args):
+        super(AlwaysOnPlugin, self).configure(*args, **kw_args)
+        self.enabled = True  # Force this plugin to be always enabled.
+
+
+class ResultPlugin(AlwaysOnPlugin):
     """
     Captures the TestResult object for later inspection.
 
@@ -10,37 +35,34 @@ class ResultPlugin(object):
     """
 
     name = "result"
-    enabled = True
 
     def finalize(self, result):
         self.result = result
 
 
-class DjangoSetUpPlugin(object):
+class DjangoSetUpPlugin(AlwaysOnPlugin):
     """
     Configures Django to setup and tear down the environment.
     This allows coverage to report on all code imported and used during the
     initialisation of the test runner.
+
     """
-
     name = "django setup"
-    enabled = True
-
-    # We need this to run before the coverage plugin (which has a score
-    # of 500), so that we still have a stdout for the user interaction
-    # Django sometimes wants to do during test database setup.
-    score = 700
 
     def __init__(self, runner):
         super(DjangoSetUpPlugin, self).__init__()
         self.runner = runner
+        self.sys_stdout = sys.stdout
 
     def begin(self):
-        """Setup the environment"""
+        sys_stdout = sys.stdout
+        sys.stdout = self.sys_stdout
+
         self.runner.setup_test_environment()
         self.old_names = self.runner.setup_databases()
 
+        sys.stdout = sys_stdout
+
     def finalize(self, result):
-        """Destroy the environment"""
         self.runner.teardown_databases(self.old_names)
         self.runner.teardown_test_environment()
